Module analysis

Module analysis 

Module with external info usefull to build dep graph, and request information about function and data entries.

Re-exports

pub use symbols::StaticModuleInfo;
pub use symbols::SymbolMap;

Modules

dep_graph
split_point
symbols

Structs

ImportInfo
ModuleInfo
Provides a additional info about module. Like ordered_data_symbols - ordered by offsets where symbol is defined (relative to module start) and info about imported functions