NamedGraph

Struct NamedGraph 

pub struct NamedGraph<Id> {
    pub module: Id,
    pub reachable: DepSet,
    /* private fields */
}

Fields

module: Idreachable: DepSet

Implementations

Source

impl<Id> NamedGraph<Id>

pub fn new(module: Id, reachable: DepSet) -> Self

pub fn imports(&self) -> &DepMiniSet

Source

impl<Id> NamedGraph<Id>

pub fn reduce_shared_entries( shared_entries: &DepSet, module_entries: &DepSet, graph: &DepGraph, ) -> DepSet

List only shared entries that have parents in module entries. This will collect nodes that module entries imports from shared entries.

pub fn calculate_shared_modules( modules: &mut [NamedGraph<Id>], graph: &DepGraph, ) -> Vec<SharedEntries<Id>>
where Id: Clone + Ord + Debug,

Calculate shared entries between modules. Returns a vector of SharedEntries, each containing a list of module names and shared dependencies. Shared dependencies are those that are reachable from multiple modules.