Module read

Module read 

Modules

code
data
linking
names
relocs

Structs

Element
Represents a core WebAssembly element segment.
Export
Represents an export in a WebAssembly module.
FuncType
Represents a type of a function in a WebAssembly module.
Global
Represents a core WebAssembly global.
Import
Represents an import in a WebAssembly module.
InputModule
Lossless representation of wasm module, without preprocessing That can pass round-trip test without any loss. After round-trip section will have canonical order.
MemoryType
Represents a memory’s type.
Table
Type information about a table defined in the table section of a WebAssembly module.
TagType
A tag’s type.