pub struct UnknownInfo<'a> {
pub ty: u8,
pub data: &'a [u8],
pub range: Range<usize>,
}Fields
ty: u8The identifier for this subsection.
data: &'a [u8]The contents of this subsection.
range: Range<usize>The range of bytes, relative to the start of the original data stream, that the contents of this subsection reside in.