Module with external info usefull to build dep graph, and request information about function and data entries.
Re-exports
pub use symbols::StaticModuleInfo;pub use symbols::SymbolMap;
Modules
Structs
- Import
Info - Module
Info - Provides a additional info about module. Like ordered_data_symbols - ordered by offsets where symbol is defined (relative to module start) and info about imported functions