pub struct NamedGraph<Id> {
pub module: Id,
pub reachable: DepSet,
/* private fields */
}Fields
module: Idreachable: DepSetImplementations
Sourceimpl<Id> NamedGraph<Id>
impl<Id> NamedGraph<Id>
Sourceimpl<Id> NamedGraph<Id>
impl<Id> NamedGraph<Id>
List only shared entries that have parents in module entries. This will collect nodes that module entries imports from shared entries.
Calculate shared entries between modules. Returns a vector of SharedEntries, each containing a list of module names and shared dependencies. Shared dependencies are those that are reachable from multiple modules.