pub enum LinkageType {
OriginalLayout,
DynamicLinking {
table_offset: u32,
table_num_entrypoints: u32,
},
}Variants
OriginalLayout
Keep original layout of data segment and indirect_function_table. This will emit “gaps” in “element” and in “data” sections.
This layout is non-portable and doesn’t support dynamic module re-building/re-loading. It is useful in production, to split size of generated WASM binaries.
DynamicLinking
Replace constant offsets with GOT+offset (for memory and table access). Allocate memory and table dynamically on module loading.
This allow dynamic reloading of modules. Modules entrypoints are still located in fixed position in table.